Machine Learning (ml module) {#tutorial_table_of_content_ml}
============================

Use the powerful machine learning classes for statistical classification, regression and clustering
of data.

-   @subpage tutorial_introduction_to_svm

    *Compatibility:* \> OpenCV 2.0

    *Author:* Fernando Iglesias García

    Learn what a Suport Vector Machine is.

-   @subpage tutorial_non_linear_svms

    *Compatibility:* \> OpenCV 2.0

    *Author:* Fernando Iglesias García

    Here you will learn how to define the optimization problem for SVMs when it is not possible to
    separate linearly the training data.

-   @subpage tutorial_introduction_to_pca

    *Compatibility:* \> OpenCV 2.0

    *Author:* Theodore Tsesmelis

    Learn what a Principal Component Analysis (PCA) is.
